# JARVIS-API-Library
This is the API python library for The J.A.R.V.I.S. Project.

# Installation

```bash
pip install jarvis-api-library
```


# Github
 - Forks of a Repository
 - Starred Repositories of a User
 - Collaborators on a Repository
 - Commits on a Repository
 - Deployments on a Repository
 - Issues on a Repository
 - Releases on a Repository
 - Followers of a User
 - A Users Following
 - A Users Repositories
 - A Repository Activity
 - The Branches of a Repository
